@@ -59,7 +59,7 @@ detach(ge03d2@phdata)
 #"CHECK DATA1 FOR STRONG GENETIC OUTLIERS"
 #"...FIRST COMPUTE GENOMIC KINSHIP USING ALL AUTOSOMAL MARKERS"
 ?"...FROM SAMPLE OF 1000 RANDOM SNPS TO AVOID LD PROBLEMS (THIS PARTICULAR SET)"
-data1.gkin <- ibs(data1[,sample(which(data1@gtdata@chromosome!="X"),1000)],weight="freq")
+data1.gkin <- ibs(data1[,sample(autosomal(data1),1000)],weight="freq")
 ?"...COMPUTE EUCLIDIAN DISTANCE AS .5-Kinship"
 data1.dist <- as.dist(0.5-data1.gkin)
 ?"...PERFORM PRINCIPAL COMPONENT ANALYSIS OF Kinship (2 COMP)"
@@ -105,7 +105,7 @@ an0 <- qtscore(dm2,ge03d2)
 ?"...PLOT THE ANALYSIS RESULTS"
 plot(an0)
 ?"...CHECK IF POPULATION IS HOMOGENIOUS (Lambda=1)"
-an0$lambda
+lambda(an0)
 ?"...COMPARE TO CORRECTED P-value"
 add.plot(an0,df="Pc1df",col="red")
 ?"...DESCRIPTIVES OF THE RESULTS, SORTED BY Pc1df"
@@ -115,7 +115,7 @@ descriptives.scan(an0,sort="Pc1df")
 ?"...RUN GWA WITH QTSCORE"
 an3 <- qtscore(dm2,data3)
 ?"...CHECK IF POPULATION IS HOMOGENIOUS (Lambda=1)"
-an3$lambda
+lambda(an3)
 ?"...PLOT THE ANALYSIS RESULTS FOR CORRECTED P-value"
 plot(an3,df="Pc1df")
 
@@ -123,7 +123,7 @@ plot(an3,df="Pc1df")
 ?"...RUN GWA WITH QTSCORE"
 an3.a <- qtscore(dm2~sex+age,data3)
 ?"...CHECK LAMBDA"
-an3.a$lambda
+lambda(an3.a)
 ?"...PLOT THE ANALYSIS RESULTS FOR CORRECTED P-value"
 plot(an3.a,df="Pc1df")
 
@@ -141,13 +141,13 @@ attach(data3@phdata)
 ?"...RUN GWA WITH QTSCORE, EXCLUDING CASES WITH BMI<30"
 an3.ob <- qtscore(dm2~sex+age,data3,ids=((bmi>=30 & dm2==1) | dm2==0))
 ?"...CHECK LAMBDA"
-an3.ob$lambda
+lambda(an3.ob)
 ?"...PLOT THE ANALYSIS RESULTS FOR CORRECTED P-value"
 plot(an3.ob,df="Pc1df")
 ?"...RUN GWA WITH QTSCORE, EXCLUDING CASES WITH BMI>=30"
 an3.nob <- qtscore(dm2~sex+age,data3,ids=((bmi<30 & dm2==1) | dm2==0))
 ?"...CHECK LAMBDA"
-an3.nob$lambda
+lambda(an3.nob)
 ?"...PLOT THE ANALYSIS RESULTS FOR CORRECTED P-value"
 plot(an3.nob,df="Pc1df")
 
@@ -194,7 +194,7 @@ strata <- 1*(data1@phdata$id %in% cl1)
 ?"...RUN ANALYSIS"
 an4.sa <- qtscore(dm2~sex+age,data1,strata=strata)
 ?"...CHECK LAMBDA"
-an4.sa$lambda
+lambda(an4.sa)
 ?"...COMPARE RESULTS; SA = RED"
 plot(an4.sa,ylim=c(0,7),col="red",df="Pc1df")
 ?"...ANALYSIS EXCLUSING OUTLIERS = BLUE"
@@ -205,7 +205,7 @@ add.plot(an0,col="green",df="Pc1df")
 #"EIGENVALUE ANALYSIS"
 an4.eg <- egscore(dm2~sex+age,data1,kin=data1.gkin)
 ?"...CHECK LAMBDA"
-an4.eg$lambda
+lambda(an4.eg)
 ?"...COMPARE RESULTS; SA = RED, W/O OUTLIERS = BLUE, WITH OUTLIERS = GREEN"
 plot(an4.sa,ylim=c(0,7),col="red",df="Pc1df")
 add.plot(an3.a,col="blue",df="Pc1df")
@@ -255,24 +255,24 @@ snppos <- data1@gtdata@map[which(data1@gtdata@snpnames==snp)]
 reg <- snp.names(data1,begin=snppos-150000,end=snppos+150000)
 reg
 ?"ONE SNP ANALYSES"
-reg.qt <- qtscore(dm2~sex+age,data1[,reg],clam=an4.sa$lam$est)
-print(min(reg.qt$P1df))
-reg.glm <- scan.glm("dm2~sex+age+CRSNP",data=data2[,reg]) #,clam=an4.sa$lam$est)
-print(min(reg.glm$P1df))
+reg.qt <- qtscore(dm2~sex+age,data1[,reg],clam=lambda(an4.sa)$estimate)
+print(min(reg.qt[,"P1df"]))
+reg.glm <- mlreg(dm2~sex+age,data=data2[,reg],trait="binomial") #,clam=an4.sa$lam$est)
+print(min(reg.glm[,"P1df"]))
 ?"HAPLOTYPE ANALYSIS IN SLIDING WINDOW"
 reg.h2 <- scan.haplo(dm2~sex+age+CRSNP,data2[,reg],trait.type="binomial")
-print(min(reg.h2$P1df))
+print(min(reg.h2[,"P1df"]))
 reg.h3 <- scan.haplo(dm2~sex+age+CRSNP,data2[,reg],n.slide=3,trait.type="binomial")
-print(min(reg.h3$P1df))
+print(min(reg.h3[,"P1df"]))
 ?"PLOT RESULTS"
-minp <- min(reg.qt$P1df,reg.glm$P1df,reg.h2$P1df,reg.h3$P1df)
+minp <- min(reg.qt[,"P1df"],reg.glm[,"P1df"],reg.h2[,"P1df"],reg.h3[,"P1df"])
 print(minp)
 plot(reg.qt,ylim=c(0,ceiling(-log10(minp))))
 add.plot(reg.glm,cex=2)
 add.plot(reg.h2,col="green",typ="l")
 add.plot(reg.h3,col="blue",typ="l")
 ?"DO 2D HAPLOTYPE ANALYSIS IN 50 KB REGION OF THE PEAK"
-bpos <- reg.h2$map[which.min(reg.h2$P1df)]
+bpos <- annotation(reg.h2)$Position[which.min(reg.h2[,"P1df"])]
 sreg <- snp.names(data2,begin=bpos-25000,end=bpos+25000)
 sreg
 sreg.h2D <- scan.haplo.2D(dm2~age+sex+CRSNP,data2[,sreg],trait.type="binomial")
@@ -280,5 +280,5 @@ print(min(sreg.h2D$P1df,na.rm=T))
 plot(sreg.h2D)
 ?"DO LD ANALYSIS AND UPDATE THE PLOT"
 if (!require(genetics)) stop("you need to install library 'genetics' to see this part of demo")
-sreg.LD <- LD(as.genotype(data2@gtdata[,sreg]))
+sreg.LD <- LD(as.genotype(gtdata(data2[,sreg])))
 image(sreg.h2D$map,sreg.h2D$map,t(sreg.LD$"D'"),add=T)
